@@ -10,8 +10,8 @@
 #include "fakenetworkaccessmanagerfactory.h"
 #include "testutils.h"
 
-#include "createjob.h"
 #include "account.h"
+#include "createjob.h"
 
 Q_DECLARE_METATYPE(QList<FakeNetworkAccessManager::Scenario>)
 
@@ -54,7 +54,6 @@ private:
     QByteArray mResponse;
 };
 
-
 class CreateJobTest : public QObject
 {
     Q_OBJECT
@@ -68,22 +67,28 @@ private Q_SLOTS:
     {
         QTest::addColumn<QList<FakeNetworkAccessManager::Scenario>>("scenarios");
 
-        QTest::newRow("success") << Scenarios{
-            { QUrl(QStringLiteral("https://example.test/request/data?prettyPrint=false")), QNetworkAccessManager::PostOperation,
-              "New data", 200, "Data created" }
-        };
+        QTest::newRow("success") << Scenarios{{QUrl(QStringLiteral("https://example.test/request/data?prettyPrint=false")),
+                                               QNetworkAccessManager::PostOperation,
+                                               "New data",
+                                               200,
+                                               "Data created"}};
 
-        QTest::newRow("creation failed") << Scenarios{
-            { QUrl(QStringLiteral("https://example.test/request/data?prettyPrint=false")), QNetworkAccessManager::PostOperation,
-              "New data", KGAPI2::Forbidden, {} }
-        };
+        QTest::newRow("creation failed") << Scenarios{{QUrl(QStringLiteral("https://example.test/request/data?prettyPrint=false")),
+                                                       QNetworkAccessManager::PostOperation,
+                                                       "New data",
+                                                       KGAPI2::Forbidden,
+                                                       {}}};
 
-        QTest::newRow("redirect") << Scenarios{
-            { QUrl(QStringLiteral("https://example.test/request/data?prettyPrint=false")), QNetworkAccessManager::PostOperation,
-              "New data", KGAPI2::TemporarilyMoved, "https://example.test/moved/data" },
-            { QUrl(QStringLiteral("https://example.test/moved/data?prettyPrint=false")), QNetworkAccessManager::PostOperation,
-              "New data", KGAPI2::OK, "Data created" }
-        };
+        QTest::newRow("redirect") << Scenarios{{QUrl(QStringLiteral("https://example.test/request/data?prettyPrint=false")),
+                                                QNetworkAccessManager::PostOperation,
+                                                "New data",
+                                                KGAPI2::TemporarilyMoved,
+                                                "https://example.test/moved/data"},
+                                               {QUrl(QStringLiteral("https://example.test/moved/data?prettyPrint=false")),
+                                                QNetworkAccessManager::PostOperation,
+                                                "New data",
+                                                KGAPI2::OK,
+                                                "Data created"}};
     }
 
     void testCreate()
