@@ -6,8 +6,7 @@
  * SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
  */
 
-#ifndef KGAPI2_DRIVEAPPFETCHJOB_H
-#define KGAPI2_DRIVEAPPFETCHJOB_H
+#pragma once
 
 #include "fetchjob.h"
 #include "kgapidrive_export.h"
@@ -21,18 +20,16 @@ namespace Drive
 class KGAPIDRIVE_EXPORT AppFetchJob : public KGAPI2::FetchJob
 {
     Q_OBJECT
-  public:
+public:
     explicit AppFetchJob(const AccountPtr &account, QObject *parent = nullptr);
-    explicit AppFetchJob(const QString &appId, const AccountPtr &account,
-                         QObject *parent = nullptr);
+    explicit AppFetchJob(const QString &appId, const AccountPtr &account, QObject *parent = nullptr);
     ~AppFetchJob() override;
 
-  protected:
+protected:
     void start() override;
-    KGAPI2::ObjectsList handleReplyWithItems(const QNetworkReply *reply,
-                                                     const QByteArray &rawData) override;
+    KGAPI2::ObjectsList handleReplyWithItems(const QNetworkReply *reply, const QByteArray &rawData) override;
 
-  private:
+private:
     class Private;
     Private *const d;
     friend class Private;
@@ -41,5 +38,3 @@ class KGAPIDRIVE_EXPORT AppFetchJob : public KGAPI2::FetchJob
 } // namespace Drive
 
 } // namespace KGAPI2
-
-#endif // KGAPI2_DRIVEAPPFETCHJOB_H
